
TODO: TODO_89_50_17_63: fine-tune list of `index_prop`-s

Initially, when FS_45_08_22_15 index model API was first introduced,
the list of `index_prop`-s for index models were defined lazily (BAU) -
the same list of `index_prop`-s is defined the one used before.

However, to make it look sane for FS_74_69_61_79 get set data envelope funcs,
the list should not include fields unrelated to the given `envelope_class`.
